Condition enum

Inheritance
Available extensions

Values

isLength8 → const Condition
specialCharacter → const Condition
isEmail → const Condition
onlyKor → const Condition
onlyEng → const Condition
onlyLetter → const Condition
isContainUpperCase → const Condition
onlyNumber → const Condition
isContainSpace → const Condition

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<Condition>
A constant List of the values in this enum, in order of their declaration.